@@ -29,6 +29,7 @@
 #include <KConfigGroup>
 #include <KSharedConfig>
 #include <QDebug>
+#include <KCrash>
 #include <Kdelibs4ConfigMigrator>
 
 #include "rsiwidget.h"
@@ -46,7 +47,7 @@ int main( int argc, char *argv[] )
 
     KAboutData aboutData( "rsibreak",
                           i18n( "RSIBreak" ),
-                          "0.12.2",
+                          "0.12.3",
                           i18n( "Try to prevent Repetitive Strain Injury by "
                                  "reminding a user to rest." ),
                           KAboutLicense::GPL,
@@ -87,6 +88,8 @@ int main( int argc, char *argv[] )
             return 0;
     }
 
+    KCrash::initialize();
+
     new RSIObject();
     return app.exec();
 }
